@@ -1,7 +1,7 @@
-__version__ = '0.4.0'
+__version__ = '0.5.0'
 __author__ = 'Robert James, Fiona Alder'
 __author_email__ = 'robert.james.19@ucl.ac.uk'
 
 from .utils import *
 from .socket_thread import *
-from .stream_data import *
+from .device_interface import *
